@@ -154,7 +154,7 @@ class KerasJsonModelImport:
             return arg.tolist()
         if isinstance(arg, (str, float, int, bool, type(None))):
             return arg
-        if isinstance(arg, list):
+        if isinstance(arg, (list, tuple)):
             return [KerasJsonModelImport._serialize_arg(a) for a in arg]
         if isinstance(arg, dict):
             return {k: KerasJsonModelImport._serialize_arg(v) for k, v in arg.items()}
